@@ -2,7 +2,7 @@ plot.rocJM <-
 function (x, which = NULL, type = c("ROC", "AUC"), 
     ndt = "all", main = NULL, caption = NULL, xlab = NULL, ylab = NULL, 
     ask = NULL, legend = FALSE, lx = NULL, ly = NULL, lty = NULL, col = NULL, 
-    cex.caption = 0.8, ...) {
+    cex.caption = 0.8, cex.axis = NULL, cex.lab = NULL, cex.main = NULL, ...) {
     type <- match.arg(type)
     if (is.null(which))
         which <- grep("MCresults", names(x))
@@ -18,7 +18,7 @@ function (x, which = NULL, type = c("ROC", "AUC"),
         main <- paste("Case", names(x$times))
     if (is.null(caption))
         caption <- sapply(x$times, function (xx) {
-            paste("(Follow-up times: ", 
+            paste("(Follow-up time(s): ", 
                 paste(round(xx, 1), collapse = ", "), ")", sep = "")
         })
     if (type == "ROC") {
@@ -37,11 +37,14 @@ function (x, which = NULL, type = c("ROC", "AUC"),
             if (ndt == "all") {
                 matplot(t(1 - rr$Spec), t(rr$Sen), type = "l", lty = lty, col = col., 
                     ylim = c(0, 1), xlim = c(0, 1), xlab = xlab, 
-                    ylab = ylab, main = main[ii], ...)
+                    ylab = ylab, main = main[ii], cex.axis = cex.axis, 
+                    cex.lab = cex.lab, cex.main = cex.main, ...)
                 abline(a = 0, b = 1, col = "grey")
                 mtext(caption[ii], 3, 0.25, cex = cex.caption)
                 if (legend) {
                     labs <- if (is.list(rnams)) rnams[[i]] else rnams
+                    labs <- sapply(rnams, function (n)
+                        as.expression(substitute(paste(Delta, "t = ", n), list("n" = n))))
                     legend(lx, ly, labs, lty = lty, col = col., bty = "n", ...)
                 }
             } else {
@@ -49,11 +52,14 @@ function (x, which = NULL, type = c("ROC", "AUC"),
                     round(seq(1, nr, length.out = ndt))
                 matplot(t(1 - rr$Spec)[, ind], t(rr$Sen)[, ind], 
                     type = "l", lty = lty, col = col., ylim = c(0, 1), 
-                    xlim = c(0, 1), xlab = xlab, ylab = ylab, main = main[ii], ...)
+                    xlim = c(0, 1), xlab = xlab, ylab = ylab, main = main[ii], 
+                    cex.axis = cex.axis, cex.lab = cex.lab, cex.main = cex.main, ...)
                 abline(a = 0, b = 1, col = "grey")            
                 mtext(caption[ii], 3, 0.25, cex = cex.caption)
                 if (legend) {
                     labs <- if (is.list(rnams)) rnams[[i]] else rnams 
+                    labs <- sapply(rnams, function (n)
+                        as.expression(substitute(paste(Delta, "t = ", n), list("n" = n))))
                     legend(lx, ly, labs[ind], lty = lty, col = col., bty = "n", ...)
                 }
             } 
@@ -84,10 +90,10 @@ function (x, which = NULL, type = c("ROC", "AUC"),
             round(seq(1, nr, length.out = ndt))
         matplot(as.numeric(rownames(aucs))[ind.time], 
             aucs[ind.time, ind.which, drop = FALSE], type = "l", 
-            lty = lty, col = col., xlab = xlab, ylab = ylab, ...)
+            lty = lty, col = col., xlab = xlab, ylab = ylab, 
+            cex.axis = cex.axis, cex.lab = cex.lab, ...)
         if (legend)
             legend(lx, ly, main, lty = lty, col = col., bty = "n", ...)
     }
     invisible()
 }
-
